==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/crm_checklist/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'CRM - Implementação de checklist de tarefas',
    'version': '7.0.21.12.14',
    'category': 'CRM',
    'description': """ Este Modulo implementa checklist ao modulo crm""",
    'author': 'Tiny',
    'website': 'http://www.siginformatica.com',
    'depends': [
        'crm_br',
    ],
    'data': [
        'views/checklist_capa_view.xml',
        'wizard/gerar_atividades_view.xml',
        'inherit/crm/crm_br_case_view.xml',
        'views/actions.xml',
        'views/menu.xml',

        'security/ir.model.access.csv'
    ],
    'installable': True,
    "application": True,
    'active': False,
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/crm_checklist/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'CRM - Implementação de checklist de tarefas',
    'version': '7.0.2310.2',
    'category': 'CRM',
    'description': """ Este Modulo implementa checklist ao modulo crm""",
    'author': 'Tiny',
    'website': 'http://www.siginformatica.com',
    'depends': [
        'crm_br',
    ],
    'data': [
        'views/checklist_capa_view.xml',
        'wizard/gerar_atividades_view.xml',
        'inherit/crm/crm_br_case_view.xml',
        'views/actions.xml',
        'views/menu.xml',

        'security/ir.model.access.csv'
    ],
    'installable': True,
    "application": True,
    'active': False,
}
